@@ -53,7 +53,7 @@ class InstanceEndpointAclPolicy(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["InstanceEndpointAclPolicyProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[InstanceEndpointAclPolicyProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -234,7 +234,7 @@ class Namespace(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["NamespaceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[NamespaceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -392,7 +392,7 @@ class Repository(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RepositoryProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RepositoryProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -481,7 +481,7 @@ class RepositoryProps:
                 summary: typing.Union[builtins.str, ros_cdk_core.IResolvable],
                 detail: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
                 instance_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
-                repo_source: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosRepository.RepoSourceProperty", typing.Dict[str, typing.Any]]]] = None,
+                repo_source: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosRepository.RepoSourceProperty, typing.Dict[str, typing.Any]]]] = None,
                 tag_immutability: typing.Optional[typing.Union[builtins.bool, ros_cdk_core.IResolvable]] = None,
             ) -> None:
                 ...
@@ -615,7 +615,7 @@ class RosInstanceEndpointAclPolicy(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosInstanceEndpointAclPolicyProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosInstanceEndpointAclPolicyProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -987,7 +987,7 @@ class RosNamespace(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosNamespaceProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosNamespaceProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1283,7 +1283,7 @@ class RosRepository(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosRepositoryProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosRepositoryProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1527,7 +1527,7 @@ class RosRepository(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosRepository.RepoSourceProperty"]],
+                value: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosRepository.RepoSourceProperty]],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -1883,7 +1883,7 @@ class RosUserInfo(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosUserInfoProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosUserInfoProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -1967,7 +1967,7 @@ class RosUserInfo(
     ) -> None:
         if __debug__:
             def stub(
-                value: typing.Union[ros_cdk_core.IResolvable, "RosUserInfo.UserProperty"],
+                value: typing.Union[ros_cdk_core.IResolvable, RosUserInfo.UserProperty],
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -2098,7 +2098,7 @@ class UserInfo(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["UserInfoProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[UserInfoProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
